import { Fragment, useEffect, useState } from "react";
import {faDate} from "../../../functions/date";

import {MdUpdate} from "react-icons/md";
import { original, serialize } from "../../../functions/helper";
import API from "../../../api/baseUrl";
import loader from "../../../assets/loader.svg";

export default function Appointments() {

    const Login_User_Token = localStorage.getItem("user_login_token");
    const Login_User_cp = localStorage.getItem("user_login_cp");

    const [timer, setTimer] = useState(60);
    const [updateFlag, setUpdateFlag] = useState(455)
    const [appointments, setAppointments] = useState([]);
    const [loading, setLoading] = useState(true);



    useEffect(() => {
        fetchData();
        clearInterval(window.appointmentsTimer)

        window.appointmentsTimer = window.setInterval(() => {
            fetchData();
            // console.log(timer);
        }, timer * 1000);

    }, [updateFlag]);


    const handleUpdate = () => {
        fetchData();
        setUpdateFlag(Math.random() * updateFlag)
    }


    
    const fetchData = async () => {
        try {
            // setLoading(true)
          const res = await API.post(
            serialize({
              id: 2345,
              sp_param: `'${faDate}','${Login_User_cp}'`,
              Login_User_Token,
              Login_User_cp,
            })
          );
          let resParse = original(res.data, false);
            console.log(resParse);
          setAppointments(resParse);
          setLoading(false);

   

        } catch (error) {
          // swal("", `${error}`, "warning");
          console.log(error);
        }
      };

    return (
      <Fragment>
        <div className="panel-head">
            <h2 className="panel-head__title">همه وقت ها</h2>
        </div>
        <div className="appointments-page panel-page__paper">
            <div className="appointments-page__form">
                <div className="text-input">
                    <input className="text-input__input" value={faDate}/>
                </div>
                <div className="text-input" style={{width: "85px"}}>
                    <input className="text-input__input" style={{textAlign: "center"}} value={timer} onChange={(e) => setTimer(e.target.value)} />
                </div>
                <button className="appointments-page__form_btn" onClick={handleUpdate}><MdUpdate /></button>
            </div>

            <div className="appointments">
                {
                    !loading ? (
                        <table className="table">
                        <thead>
                            <tr>
                                {Object.keys(appointments[0]).map((item, i) => (
                                    <th key={i}>{item}</th>
                                ))}
                            </tr>
                        </thead>
                        <tbody>
                            {
                                appointments.map((item, index) => (
                                    <tr key={index}>
                                        {
                                            Object.entries(item).map(([key, value], index) => (
                                                <td key={index}>{value}</td>
                                            ))
                                        }
                                    </tr>
                                ))
                            }
                        </tbody>
                    </table>
                    ) : (
                        <div className="loader-container">
                            <img src={loader} />
                        </div>
                    )
                }
               
            </div>
        </div>
      </Fragment>
    )
}
